# data-degradation-detector

[![Tests](https://github.com/aloncrack7/data-degradation-detector/actions/workflows/tests.yml/badge.svg)](https://github.com/aloncrack7/data-degradation-detector/actions/workflows/tests.yml)
[![PyPI version](https://badge.fury.io/py/data-degradation-detector.svg)](https://badge.fury.io/py/data-degradation-detector)
[![Python Support](https://img.shields.io/pypi/pyversions/data-degradation-detector.svg)](https://pypi.org/project/data-degradation-detector/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

Library to make estimations on data degradation

## Installation

```bash
pip install data-degradation-detector
```

## Development

### Running Tests

```bash
python -m pytest testing/ -v
```
